﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Shapes;
using System.Xml.Linq;
using ChartFX.WPF;
using ChartFX.WPF.Animation;
using ChartFX.WPF.Converters;

namespace ChartFXforWPF_Demo
{
    /// <summary>
    /// Interaction logic for ChartDemo.xaml
    /// </summary>
    public partial class ChartDemo : Window
    {
        public ChartDemo()
        {
            InitializeComponent();
            chart1.View3D.Cluster = TriState.Yes;
            
            string path = System.Reflection.Assembly.GetExecutingAssembly().Location;
            path = System.IO.Path.Combine(System.IO.Path.GetDirectoryName(path), "XMLdata.xml");
            XDocument dataXml = XDocument.Load(path);

            var xmlData = from yearlyData in dataXml.Descendants("Year")
                          select new
                          {
                              myYear = yearlyData.Attribute("name").Value,
                              USA = yearlyData.Element("USA").Value,
                              CHINA = yearlyData.Element("CHINA").Value,
                              JAPAN = yearlyData.Element("JAPAN").Value,
                              GERMANY = yearlyData.Element("GERMANY").Value
                          };

            InitializeChart(chart1);
            chart1.ItemsSource = xmlData;
            
        }

        private void InitializeChart(Chart chart)
        {
            chart.Series.Clear();
            SeriesAttributes series1 = new SeriesAttributes();
            series1.BindingPath = "USA";
            chart.Series.Add(series1);

            SeriesAttributes series2 = new SeriesAttributes();
            series2.BindingPath = "CHINA";
            chart.Series.Add(series2);

            SeriesAttributes series3 = new SeriesAttributes();
            series3.BindingPath = "JAPAN";
            chart.Series.Add(series3);

            SeriesAttributes series4 = new SeriesAttributes();
            series4.BindingPath = "GERMANY";
            chart.Series.Add(series4);

            chart.AxisX.Labels.BindingPath = "myYear";

            chart.Titles.Add(new Title("Number of Broadband Subscribers"));
            chart.Titles.Add(new Title("Per One Hundred People"));

            chart.LegendBox.Visibility = Visibility.Visible;
            chart.AllSeries.StackedStyle = StackedStyle.Normal;
            chart.View3D.AngleX = 20;
            chart.View3D.AngleY = 30;
            chart.View3D.Lights.Add((System.Windows.Media.Media3D.Light)FindResource("Light1"));
            chart.View3D.Lights.Add((System.Windows.Media.Media3D.Light)FindResource("Light2"));
            chart.View3D.Lights.Add((System.Windows.Media.Media3D.Light)FindResource("Light3"));
            chart.View3D.Lights.Add((System.Windows.Media.Media3D.Light)FindResource("Light4"));
            chart.View3D.Lights.Add((System.Windows.Media.Media3D.Light)FindResource("Light5"));
            chart.View3D.Lights.Add((System.Windows.Media.Media3D.Light)FindResource("Light6"));
            chart.Zoom.MagnifierTemplate = (DataTemplate)FindResource("MagnifyingGlass");

        }

      
        private void rbStyle_None_Checked(object sender, RoutedEventArgs e)
        {
            
            chart1.Template = (ControlTemplate)FindResource("Default_Template");
            chart1.BorderTemplate = (ControlTemplate)FindResource("Default_Border");
            chart1.GalleryTemplates = null;
                     
        }

        private void rbStyle_Glass_Checked(object sender, RoutedEventArgs e)
        {
            try
            {
                chart1.Template = (ControlTemplate)FindResource("Glass_Template");
                chart1.BorderTemplate = (ControlTemplate)FindResource("Glass_Border");
                chart1.GalleryTemplates = (ResourceDictionary)FindResource("GalleryGlass");
            }
            catch { }
        
        }
      
        private void rbStyle_Spotlight_Checked(object sender, RoutedEventArgs e)
        {
            
            chart1.BorderTemplate = (ControlTemplate)FindResource("Spotlight_Border");
            chart1.Template = (ControlTemplate)FindResource("Spotlight_Template");
            chart1.GalleryTemplates = (ResourceDictionary)FindResource("GallerySpotlight");
                        
        }

        private void rbStyle_Edge_Checked(object sender, RoutedEventArgs e)
        {

            chart1.Template = (ControlTemplate)FindResource("Edge_Template");
            chart1.BorderTemplate = (ControlTemplate)FindResource("Edge_Border");
            chart1.GalleryTemplates = (ResourceDictionary)FindResource("GalleryEdge");
                   
        }
      
        private void rbPalette0_Checked(object sender, RoutedEventArgs e)
        {
            chart1.Palette = (Palette)FindResource("Basic_Palette");
  
        }
        
        private void rbPalette1_Checked(object sender, RoutedEventArgs e)
        {
            try
            {
                chart1.Palette = (Palette)FindResource("Dark_Palette");
            }
            catch { }
           
        }
        
        private void rbPalette2_Checked(object sender, RoutedEventArgs e)
        {
            chart1.Palette = (Palette)FindResource("Frost_Palette");
 
        }

        private void BarRadioButton_Checked(object sender, RoutedEventArgs e)
        {
            try {
                chart1.Gallery = Gallery.Bar;
                chkAnimate.IsEnabled = true;
                chkAnimate.Opacity = 1;
                chart1.View3D.AngleX = 20;
                chart1.View3D.AngleY = 30;
                if (!(bool)chkEnable3D.IsChecked)
                    chart1.AllSeries.StackedStyle = StackedStyle.Normal;
                else
                    chart1.AllSeries.StackedStyle = StackedStyle.No;
                chart1.View3D.Cluster = TriState.Yes;
            }
            catch { }

        }
        
        private void PieRadioButton_Checked(object sender, RoutedEventArgs e)
        {
            chart1.Gallery = Gallery.Pie;
            chkAnimate.IsChecked = false;
            chkAnimate.IsEnabled = false;
            chkAnimate.Opacity = 0.3;
            chart1.View3D.AngleX = -10;
            chart1.View3D.AngleY = 40;
            chart1.AllSeries.Animation = null;
            chart1.AllSeries.StackedStyle = StackedStyle.No;
            chart1.View3D.Cluster = TriState.Auto;
            
        }
        
        private void AreaRadioButton_Checked(object sender, RoutedEventArgs e)
        {
            chart1.Gallery = Gallery.Area;
            chkAnimate.IsChecked = false;
            chkAnimate.IsEnabled = false; 
            chkAnimate.Opacity = 0.3;
            chart1.AllSeries.StackedStyle = StackedStyle.Normal;
            chart1.View3D.AngleX = 20;
            chart1.View3D.AngleY = 30;
            chart1.AllSeries.Animation = null;
            chart1.View3D.Cluster = TriState.No;

        }
        
        private void Toggle3D(object sender, RoutedEventArgs e)
        {
            if ((bool)chkEnable3D.IsChecked)
            {
                Message3D.Visibility = Visibility.Visible;
                chkAnimate.IsEnabled = true;
                chkAnimate.Opacity = 1;
                if (chart1.Gallery == Gallery.Bar)
                    chart1.AllSeries.StackedStyle = StackedStyle.No;
            }
            else {
                if (chart1.Gallery == Gallery.Bar)
                    chart1.AllSeries.StackedStyle = StackedStyle.Normal;
            }

            chkAnimate.IsEnabled = !((bool)chkEnable3D.IsChecked);
            chkAnimate.Opacity = 0.3;
            chart1.View3D.IsEnabled = (bool)chkEnable3D.IsChecked;

        }

        private void ToggleZoom(object sender, RoutedEventArgs e)
        {
            if ((bool)chkZoom.IsChecked)
                chart1.Zoom.Mode = ZoomMode.Magnifier;
            else
                chart1.Zoom.Mode = ZoomMode.Off;
        }

        private void ToggleAnimation(object sender, RoutedEventArgs e)
        {
            if ((bool)chkAnimate.IsChecked)
            {
                chart1.AllSeries.Animation = (SeriesAnimation)FindResource("SimpleAnimation");
            }
            else 
            {
                chart1.AllSeries.Animation = null;
            }
        }
    }
}
